@@ -703,6 +703,7 @@ public:
     {
         return _hasGraphics;
     }
+    void setIgnoreWcWidth(bool ignore);
 
 private:
     // copies a line of text from the screen or history into a stream using a
@@ -809,6 +810,7 @@ private:
     bool _enableReflowLines;
 
     std::vector<LineProperty> _lineProperties;
+    LineProperty linePropertiesAt(unsigned int line);
 
     // history buffer ---------------
     std::unique_ptr<HistoryScroll> _history;
@@ -899,6 +901,9 @@ private:
     std::vector<std::unique_ptr<TerminalGraphicsPlacement_t>> _graphicsPlacements;
     void scrollPlacements(int n, qint64 below = INT64_MAX, qint64 above = INT64_MAX);
     bool _hasGraphics;
+
+    //
+    bool _ignoreWcWidth;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Screen::DecodingOptions)
