@@ -704,7 +704,10 @@ void EditProfileDialog::selectInitialDir()
 
 void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
 {
-    auto delegate = new ColorSchemeViewDelegate(this);
+    auto compositingActiveHelper = [] {
+        return WindowSystemInfo::compositingActive();
+    };
+    auto delegate = new ColorSchemeViewDelegate(compositingActiveHelper, this);
     _appearanceUi->colorSchemeList->setItemDelegate(delegate);
 
     _appearanceUi->transparencyWarningWidget->setVisible(false);
@@ -873,6 +876,9 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
 
     _appearanceUi->wordModeBrahmic->setChecked(profile->property<bool>(Profile::WordModeBrahmic));
     connect(_appearanceUi->wordModeBrahmic, &QPushButton::toggled, this, &EditProfileDialog::toggleWordModeBrahmic);
+
+    _appearanceUi->ignoreWcWidth->setChecked(profile->property<bool>(Profile::IgnoreWcWidth));
+    connect(_appearanceUi->ignoreWcWidth, &QPushButton::toggled, this, &EditProfileDialog::toggleIgnoreWcWidth);
 }
 
 void EditProfileDialog::setAntialiasText(bool enable)
@@ -1294,7 +1300,7 @@ void EditProfileDialog::showColorSchemeEditor(bool isNewScheme)
     if (_colorDialog != nullptr) {
         closeColorSchemeEditor();
     }
-    _colorDialog = new ColorSchemeEditor(this);
+    _colorDialog = new ColorSchemeEditor(WindowSystemInfo::compositingActive(), this);
 
     connect(_colorDialog, &Konsole::ColorSchemeEditor::colorSchemeSaveRequested, this, &Konsole::EditProfileDialog::saveColorScheme);
     _colorDialog->setup(colors, isNewScheme);
@@ -1411,7 +1417,7 @@ void EditProfileDialog::updateTransparencyWarning()
 
         if (!needTransparency) {
             _appearanceUi->transparencyWarningWidget->setHidden(true);
-        } else if (!KWindowSystem::compositingActive()) {
+        } else if (!WindowSystemInfo::compositingActive()) {
             _appearanceUi->transparencyWarningWidget->setText(
                 i18n("This color scheme uses a transparent background"
                      " which does not appear to be supported on your"
@@ -1865,6 +1871,7 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
     auto codecAction = new KCodecAction(this);
     codecAction->setCurrentCodec(profile->defaultEncoding());
     _advancedUi->selectEncodingButton->setMenu(codecAction->menu());
+#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 103, 0)
     connect(codecAction,
 #if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
             QOverload<QTextCodec *>::of(&KCodecAction::codecTriggered),
@@ -1874,6 +1881,11 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
             this,
 #endif
             &Konsole::EditProfileDialog::setDefaultCodec);
+#else
+    connect(codecAction, &KCodecAction::codecNameTriggered, this, [this](const QString &codecName) {
+        setDefaultCodec(QTextCodec::codecForName(codecName.toUtf8()));
+    });
+#endif
 
     connect(codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
         setDefaultCodec(QTextCodec::codecForLocale());
@@ -2080,3 +2092,8 @@ void EditProfileDialog::toggleWordModeBrahmic(bool mode)
 {
     updateTempProfileProperty(Profile::WordModeBrahmic, mode);
 }
+
+void EditProfileDialog::toggleIgnoreWcWidth(bool ignore)
+{
+    updateTempProfileProperty(Profile::IgnoreWcWidth, ignore);
+}
